@@ -13,7 +13,7 @@ use constant RESOURCE_TYPES => [qw(
     DIALOG	STRING		FONTDIR		FONT	    ACCELERATOR
     RCDATA	MESSAGETABLE	GROUP_CURSOR	_	    GROUP_ICON
     _		VERSION		DLGINCLUDE	_	    PLUGPLAY
-    VXD		ANICURSOR	ANIICON		HTML
+    VXD		ANICURSOR	ANIICON		HTML        MANIFEST
 )];
 use constant RT_TO_ID => {
     map { ('RT_'.RESOURCE_TYPES->[$_] => $_) }
